#[non_exhaustive]pub enum ComponentError {
Generation {
expected: u64,
got: u64,
},
State {
operation: &'static str,
state: ComponentState,
},
WrongPeer {
expected: SocketAddr,
got: SocketAddr,
},
}Expand description
A rejected component transition.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Generation
ICE selected a pair from a generation this gate does not own.
State
An operation was attempted outside its one permitted phase.
WrongPeer
DTLS was asked to start for a source other than the selected peer.