pub enum IngressDisposition {
Accepted(IngressClass),
Dropped(IngressDrop),
}Expand description
Result of applying both classification and the component security state.
Variants
Accepted(IngressClass)
The named protocol may consume this datagram now.
Dropped(IngressDrop)
The datagram was accounted for and must be released.