establish_verified

Function establish_verified 

pub fn establish_verified<H: Handshake>(
    handshake: &mut H,
    role: Role,
    peer_fingerprint: Option<&Fingerprint>,
) -> Result<VerifiedKeys, Error>
Handshake, verify and return key material carrying proof that verification ran.

This has the same protocol behavior and errors as establish. Its distinct return type is for composition boundaries that must make skipping fingerprint verification unrepresentable.