pub fn find_local(
candidates: &[LocalCandidate],
id: LocalId,
) -> Option<&LocalCandidate>Expand description
The local candidate with this identity, if it is still known.
pub fn find_local(
candidates: &[LocalCandidate],
id: LocalId,
) -> Option<&LocalCandidate>The local candidate with this identity, if it is still known.