pub fn find_remote(
candidates: &[RemoteCandidate],
id: RemoteId,
) -> Option<&RemoteCandidate>Expand description
The remote candidate with this identity, if it is still known.
pub fn find_remote(
candidates: &[RemoteCandidate],
id: RemoteId,
) -> Option<&RemoteCandidate>The remote candidate with this identity, if it is still known.