pub const fn type_preference(kind: CandidateType) -> u8Expand description
5.1.2.2’s recommended type preference for a candidate of this type (spec 4’s table).
pub const fn type_preference(kind: CandidateType) -> u85.1.2.2’s recommended type preference for a candidate of this type (spec 4’s table).