pub struct Foundations { /* private fields */ }Expand description
Allocates foundations over the candidates as they are gathered (5.1.1.3).
Implementations
Sourceimpl Foundations
impl Foundations
Sourcepub fn assign(
&mut self,
candidate: &Gathered,
transport: Transport,
) -> LocalFoundation
pub fn assign( &mut self, candidate: &Gathered, transport: Transport, ) -> LocalFoundation
The foundation for a gathered candidate: the counter already allocated to its tuple, or the next one.
Sourcepub fn learn_remote(&mut self) -> RemoteFoundation
pub fn learn_remote(&mut self) -> RemoteFoundation
The next foundation for a peer-reflexive remote candidate (7.3.1.3): “an arbitrary value, different from the foundations of all other remote candidates”.