#[non_exhaustive]pub enum DtlsStartError {
Io(Error),
SocketShared,
Handshake(Error),
Worker(String),
}Expand description
A DTLS handshake could not take a bound media port into an SRTP session.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(Error)
The media socket could not be converted or configured for the handshake.
Something else retained the not-yet-started socket.
Handshake(Error)
Certificate verification, profile negotiation or key export failed.
Worker(String)
The bounded blocking handshake worker did not return normally.