#[non_exhaustive]pub enum SetupError {
PacketDurationTooShort(Duration),
RtcpIntervalTooShort(Duration),
RtcpMuxPayloadCollision(u8),
Codec {
codec: Codec,
direction: CodecDirection,
reason: String,
},
}Expand description
A negotiated media session that cannot be constructed safely.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PacketDurationTooShort(Duration)
Packet pacing cannot represent a frame shorter than one millisecond.
RtcpIntervalTooShort(Duration)
A configured RTCP timer must make forward progress.
RtcpMuxPayloadCollision(u8)
RFC 5761 cannot distinguish this marked RTP payload from an RTCP packet type.
Codec
The codec agreed through SDP could not create one of its stateful directions.