pub fn ordered_pair_priority(
role: Role,
local: Priority,
remote: Priority,
) -> u64Expand description
6.1.2.3’s pair priority with the operands put in the roles the formula names.
G is “the priority for the candidate provided by the controlling agent” — so which of the
two candidate priorities is G is a fact about our role, not about the pair.